This repository is a library for creating th2-check2-recon applications.

## Installation
```
pip install th2-check2-recon
```
This package can be found on [PyPI](https://pypi.org/project/th2-check2-recon/ "th2-check2-recon").
